@@ -16,21 +16,27 @@ current_user_setter = Signal(providing_args=['user'])
 
 @receiver(current_user_getter)
 def _get_current_user_from_request(sender, **kwargs):
-    """Signal handler to retrieve current user from request."""
+    """
+    Signal handler to retrieve current user from request.
+    """
     from crum import get_current_request
     return (getattr(get_current_request(), 'user', False), -10)
 
 
 @receiver(current_user_getter)
 def _get_current_user_from_thread_locals(sender, **kwargs):
-    """Signal handler to retrieve current user from thread locals."""
+    """
+    Signal handler to retrieve current user from thread locals.
+    """
     from crum import _thread_locals
     return (getattr(_thread_locals, 'user', False), 10)
 
 
 @receiver(current_user_setter)
 def _set_current_user_on_request(sender, **kwargs):
-    """Signal handler to store current user to request."""
+    """
+    Signal handler to store current user to request.
+    """
     from crum import get_current_request
     request = get_current_request()
     if request:
@@ -39,6 +45,8 @@ def _set_current_user_on_request(sender, **kwargs):
 
 @receiver(current_user_setter)
 def _set_current_user_on_thread_locals(sender, **kwargs):
-    """Signal handler to store current user on thread locals."""
+    """
+    Signal handler to store current user on thread locals.
+    """
     from crum import _thread_locals
     _thread_locals.user = kwargs['user']
